@@ -2,11 +2,12 @@ from typing import Optional
 from vocode.models.agent import AgentConfig
 from vocode.models.synthesizer import SynthesizerConfig
 from vocode.models.transcriber import TranscriberConfig
-from ..models.telephony import CallEntity, CreateOutboundCall
+from ..models.telephony import CallEntity, CreateOutboundCall, EndOutboundCall
 import requests
 from .. import api_key, BASE_URL
 
-VOCODE_OUTBOUND_CALL_URL = f"https://{BASE_URL}/create_outbound_call"
+VOCODE_CREATE_OUTBOUND_CALL_URL = f"https://{BASE_URL}/create_outbound_call"
+VOCODE_END_OUTBOUND_CALL_URL = f"https://{BASE_URL}/end_outbound_call"
 
 
 class OutboundCall:
@@ -17,16 +18,18 @@ class OutboundCall:
         agent_config: AgentConfig,
         transcriber_config: Optional[TranscriberConfig] = None,
         synthesizer_config: Optional[SynthesizerConfig] = None,
+        conversation_id: Optional[str] = None,
     ):
         self.recipient = recipient
         self.caller = caller
         self.agent_config = agent_config
         self.transcriber_config = transcriber_config
         self.synthesizer_config = synthesizer_config
+        self.conversation_id = conversation_id
 
-    def start(self):
-        return requests.post(
-            VOCODE_OUTBOUND_CALL_URL,
+    def start(self) -> str:
+        response = requests.post(
+            VOCODE_CREATE_OUTBOUND_CALL_URL,
             headers={"Authorization": f"Bearer {api_key}"},
             json=CreateOutboundCall(
                 recipient=self.recipient,
@@ -34,5 +37,19 @@ class OutboundCall:
                 agent_config=self.agent_config,
                 transcriber_config=self.transcriber_config,
                 synthesizer_config=self.synthesizer_config,
+                conversation_id=self.conversation_id,
             ).dict(),
         )
+        assert response.ok, response.text
+        data = response.json()
+        self.conversation_id = data["id"]
+
+    def end(self) -> str:
+        response = requests.post(
+            VOCODE_END_OUTBOUND_CALL_URL,
+            headers={"Authorization": f"Bearer {api_key}"},
+            json=EndOutboundCall(
+                call_id=self.conversation_id,
+            ).dict(),
+        )
+        assert response.ok, response.text
